using SoapEndpoint.Service.Flows.PauzeSignaal3.v1.LogbookService;
using SoapEndpoint.Service.Proxy.Models.Systeem;
using SoapEndpoint.Service.Proxy.ServiceProxies.Systeem.v2.ErrorMessage;
using SoapEndpoint.Tester.Scenario.Flow.PauzeSignaal3;

namespace SoapEndpoint.Tester.Scenario.Implementations.PauzeSignaal3;

public class SeSectorPubliekScenario : PauzeSignaal3ScenarioBase
{
    public override string Name => "SE sector publiek scenario";

    public override AdresboekOrganisatieModel SeOrganization =>
        Manager.Organizations.SingleOrDefault(p => p.Referentienummer.ToString()
            .Equals(Program.Configuration["SeGovernmentTestOrganizationReference"],
                StringComparison.CurrentCultureIgnoreCase));

    protected override async Task ExecuteAsync()
    {
        StartNewScenario("Happy flow 1");

        await Manager.SHV_FlowAsync(Conversation, null,
            new ShvFlowItem(BerichtType.SHV_KennisgevingPubliek),
            new ShvFlowItem(BerichtType.SHV_Beeindiging));

        StartNewScenario("Happy flow 2");

        await Manager.SHV_FlowAsync(Conversation, null,
            new ShvFlowItem(BerichtType.SHV_KennisgevingPubliek),
            new ShvFlowItem(BerichtType.SHV_Vervolgtraject));

        StartNewScenario("Happy flow 3");

        await Manager.SHV_FlowAsync(Conversation, null,
            new ShvFlowItem(BerichtType.SHV_KennisgevingPubliek, BerichtType.SE_KennisgevingAntwoord),
            new ShvFlowItem(BerichtType.SHV_Beeindiging));

        StartNewScenario("Happy flow 4");

        await Manager.SHV_FlowAsync(Conversation, null,
            new ShvFlowItem(BerichtType.SHV_KennisgevingPubliek, BerichtType.SE_KennisgevingAntwoord),
            new ShvFlowItem(BerichtType.SHV_Vervolgtraject));

        StartNewScenario("Happy flow 5");

        await Manager.SHV_FlowAsync(Conversation, null,
            new ShvFlowItem(BerichtType.SHV_KennisgevingPubliek, BerichtType.SE_GeenMedewerking));

        StartNewScenario("Foutsituatie kennisgeving");

        await Manager.SHV_SendIncorrectMessageAsync(Conversation, BerichtType.SHV_Kennisgeving, null,
            ShvKnooppuntFoutcode.Incorrectberichttypevoorsectorvanontvanger);

        StartNewScenario("Reminderbericht 1");

        var result =
            await Manager.SHV_RequestReplyAsync(Conversation, new ShvFlowItem(BerichtType.SHV_KennisgevingPubliek));
        await Manager.SHV_RequestReplyAsync(Conversation, new ShvFlowItem(BerichtType.SHV_ReminderBericht),
            result.RequestMessage);

        StartNewScenario("Reminderbericht 2");

        var result2 = await Manager.SHV_RequestReplyAsync(Conversation,
            new ShvFlowItem(BerichtType.SHV_KennisgevingPubliek, BerichtType.SE_KennisgevingAntwoord));

        await Manager.SHV_RequestReplyAsync(Conversation, new ShvFlowItem(BerichtType.SHV_ReminderBericht),
            result2.RequestMessage);

        StartNewScenario("Statusverzoek 1");

        await Manager.SHV_RequestReplyAsync(Conversation,
            new ShvFlowItem(BerichtType.SHV_KennisgevingPubliek, BerichtType.SE_KennisgevingAntwoord));

        await Manager.SE_RequestReplyAsync(Conversation,
            new SeFlowItem(BerichtType.SE_Statusverzoek, BerichtType.SHV_StatusberichtShv));
    }
}