﻿using SoapEndpoint.Service.Proxy.ServiceProxies.Systeem.v1.ErrorMessage;
using SoapEndpoint.Service.Systeem.v1.LogbookService;
using SoapEndpoint.Tester.Scenario.Flow.Schuldbemiddeling;

namespace SoapEndpoint.Tester.Scenario.Implementations.Schuldbemiddeling;

public class ReminderScenario : SchuldbemiddelingScenarioBase
{
    public override string Name => "Reminder scenario";

    protected override async Task ExecuteAsync()
    {
        StartNewScenario("Reminder scenario");

        // Send klant gemeld voor SHV
        var klantGemeldVoorShvResult = await Manager.SHV_RequestReplyAsync(Conversation,
            new ShvFlowItem(Berichttype.SHV_KlantGemeldVoorShv));

        // Send reminder message voor klant gemeld voor SHV (not allowed)
        await Manager.SHV_SendMessageAsync(Conversation, Berichttype.SHV_ReminderBericht,
            klantGemeldVoorShvResult.RequestMessage);

        // Check that the correct error is returned.
        await Manager.SHV_GetAndConfirmErrorMessage<ShvKnooppuntFoutbericht, Berichttype, ShvKnooppuntFoutcode>(
            Conversation,
            Berichttype.SYS_FoutBericht,
            ShvKnooppuntFoutcode.IncorrectberichttypevoorhetcrossReferentienummer,
            ShvKnooppuntFoutcode.Berichttypeniettoegestaanvoordehuidigestaatvandeconversatie);

        // Send saldoverzoek
        var saldoverzoekResult = await Manager.SHV_RequestReplyAsync(Conversation,
            new ShvFlowItem(Berichttype.SHV_Saldoverzoek));

        // Send saldoverzoek reminder message
        await Manager.SHV_RequestReplyAsync(Conversation,
            new ShvFlowItem(Berichttype.SHV_ReminderBericht), saldoverzoekResult.RequestMessage);

        // Send saldoverzoek antwoord 
        await Manager.SE_RequestReplyAsync(Conversation,
            new SeFlowItem(Berichttype.SE_SaldoverzoekAntwoord), saldoverzoekResult.RequestMessage);

        // Send betaalvoorstel
        var betaalvoorstelResult = await Manager.SHV_RequestReplyAsync(Conversation,
            new ShvFlowItem(Berichttype.SHV_Betaalvoorstel));

        // Send betaalvoorstel reminder message
        await Manager.SHV_RequestReplyAsync(Conversation,
            new ShvFlowItem(Berichttype.SHV_ReminderBericht), betaalvoorstelResult.RequestMessage);

        // Send betaalvoorstel antwoord 
        await Manager.SE_RequestReplyAsync(Conversation,
            new SeFlowItem(Berichttype.SE_BetaalvoorstelAntwoord), betaalvoorstelResult.RequestMessage);

        // Send reminder message for betaalvoorstel (not allowed)            
        await Manager.SHV_SendMessageAsync(Conversation, Berichttype.SHV_ReminderBericht,
            betaalvoorstelResult.RequestMessage);

        // Check that the correct error is returned.
        await Manager.SHV_GetAndConfirmErrorMessage<ShvKnooppuntFoutbericht, Berichttype, ShvKnooppuntFoutcode>(
            Conversation,
            Berichttype.SYS_FoutBericht,
            ShvKnooppuntFoutcode.Berichttypeniettoegestaanvoordehuidigestaatvandeconversatie);
    }
}