﻿using SoapEndpoint.Service.Proxy.ServiceProxies.Systeem.v1.ErrorMessage;
using SoapEndpoint.Service.Systeem.v1.LogbookService;
using SoapEndpoint.Tester.Scenario.Flow.Schuldbemiddeling;

namespace SoapEndpoint.Tester.Scenario.Implementations.Schuldbemiddeling;

public class VerlorenBerichtScenario : SchuldbemiddelingScenarioBase
{
    public override string Name => "Verloren bericht scenario";

    protected override async Task ExecuteAsync()
    {
        StartNewScenario("Verloren bericht flow SHV / SE");

        #region Klant gemeld voor SHV

        //Send klant gemeld voor SHV
        var klantGemeldVoorShv = await Manager.SHV_RequestReplyAsync(Conversation,
            new ShvFlowItem(Berichttype.SHV_KlantGemeldVoorShv, Berichttype.SE_KlantGemeldVoorShvAntwoord));

        // SE: Send verloren bericht verzoek 
        var lostMessageResult = await Manager.SE_RequestReplyAsync(Conversation,
            new SeFlowItem(Berichttype.SE_VerlorenBerichtVerzoek), klantGemeldVoorShv.RequestMessage);

        // SHV: Send the second klant gemeld voor SHV
        await Manager.SHV_RequestReplyAsync(Conversation,
            new ShvFlowItem(Berichttype.SHV_KlantGemeldVoorShv), lostMessageResult.ReplyMessage);

        // SHV: Send verloren bericht verzoek
        lostMessageResult = await Manager.SHV_RequestReplyAsync(Conversation,
            new ShvFlowItem(Berichttype.SHV_VerlorenBerichtVerzoek), klantGemeldVoorShv.ReplyMessage);

        // SE: Send the second klant gemeld voor SHV antwoord
        await Manager.SE_RequestReplyAsync(Conversation,
            new SeFlowItem(Berichttype.SE_KlantGemeldVoorShvAntwoord), lostMessageResult.RequestMessage);

        #endregion

        #region Saldoverzoek

        //Send saldoverzoek
        var saldoverzoek = await Manager.SHV_RequestReplyAsync(Conversation,
            new ShvFlowItem(Berichttype.SHV_Saldoverzoek, Berichttype.SE_SaldoverzoekAntwoord));

        // SE: Send verloren bericht verzoek 
        lostMessageResult = await Manager.SE_RequestReplyAsync(Conversation,
            new SeFlowItem(Berichttype.SE_VerlorenBerichtVerzoek), saldoverzoek.RequestMessage);

        // SHV: Send the second saldoverzoek
        await Manager.SHV_RequestReplyAsync(Conversation,
            new ShvFlowItem(Berichttype.SHV_Saldoverzoek), lostMessageResult.ReplyMessage);

        // SHV: Send verloren bericht verzoek
        lostMessageResult = await Manager.SHV_RequestReplyAsync(Conversation,
            new ShvFlowItem(Berichttype.SHV_VerlorenBerichtVerzoek), saldoverzoek.ReplyMessage);

        // SE: Send the second saldoverzoek antwoord
        await Manager.SE_RequestReplyAsync(Conversation,
            new SeFlowItem(Berichttype.SE_SaldoverzoekAntwoord), lostMessageResult.RequestMessage);

        #endregion

        #region Betaalvoorstel

        //Send betaalvoorstel
        var betaalvoorstel = await Manager.SHV_RequestReplyAsync(Conversation,
            new ShvFlowItem(Berichttype.SHV_Betaalvoorstel, Berichttype.SE_BetaalvoorstelAntwoord));

        // SE: Send verloren bericht verzoek 
        lostMessageResult = await Manager.SE_RequestReplyAsync(Conversation,
            new SeFlowItem(Berichttype.SE_VerlorenBerichtVerzoek), betaalvoorstel.RequestMessage);

        // SHV: Send the second betaalvoorstel
        await Manager.SHV_RequestReplyAsync(Conversation,
            new ShvFlowItem(Berichttype.SHV_Betaalvoorstel), lostMessageResult.ReplyMessage);

        // SHV: Send verloren bericht verzoek
        lostMessageResult = await Manager.SHV_RequestReplyAsync(Conversation,
            new ShvFlowItem(Berichttype.SHV_VerlorenBerichtVerzoek), betaalvoorstel.ReplyMessage);

        // SE: Send the second betaalvoorstel antwoord
        await Manager.SE_RequestReplyAsync(Conversation,
            new SeFlowItem(Berichttype.SE_BetaalvoorstelAntwoord), lostMessageResult.RequestMessage);

        #endregion

        #region Schuldregeling geaccordeerd

        //Send betaalvoorstel
        var betaalvoorstelGeaccepteerd = await Manager.SHV_RequestReplyAsync(Conversation,
            new ShvFlowItem(Berichttype.SHV_SchuldregelingGeaccordeerd));

        // SE: Send verloren bericht verzoek 
        lostMessageResult = await Manager.SE_RequestReplyAsync(Conversation,
            new SeFlowItem(Berichttype.SE_VerlorenBerichtVerzoek), betaalvoorstelGeaccepteerd.RequestMessage);

        // SHV: Send the second schuldregeling geaccordeerd
        await Manager.SHV_RequestReplyAsync(Conversation,
            new ShvFlowItem(Berichttype.SHV_SchuldregelingGeaccordeerd), lostMessageResult.ReplyMessage);

        #endregion

        StartNewScenario("Verkeerde antwoord op verlorenbericht");

        // Send saldo verzoek and reply saldo verzoek antwoord
        var clientGemeldVoorShvResult = await Manager.SHV_RequestReplyAsync(Conversation,
            new ShvFlowItem(Berichttype.SHV_KlantGemeldVoorShv, Berichttype.SE_KlantGemeldVoorShvAntwoord));

        // Send verloren bericht verzoek
        lostMessageResult = await Manager.SE_RequestReplyAsync(Conversation,
            new SeFlowItem(Berichttype.SE_VerlorenBerichtVerzoek), clientGemeldVoorShvResult.RequestMessage);

        // Send the incorrect reply to the lost message request
        await Manager.SHV_SendMessageAsync(Conversation, Berichttype.SHV_Saldoverzoek,
            lostMessageResult.ReplyMessage);

        // Check that the correct error is returned.
        await Manager.SHV_GetAndConfirmErrorMessage<ShvKnooppuntFoutbericht, Berichttype, ShvKnooppuntFoutcode>(
            Conversation,
            Berichttype.SYS_FoutBericht,
            ShvKnooppuntFoutcode.IncorrectberichttypevoorhetcrossReferentienummer);
    }
}