﻿using System.Reflection;
using System.Runtime.Serialization;

namespace Infrastructure.Utils.Xml;

public static class DataContractEnumHelpers
{
    public static string GetDescription<T>(T value) where T : Enum
    {
        var info = typeof(T).GetMember(value.ToString()).First();
        var attribute = info.GetCustomAttribute<EnumMemberAttribute>()
                        ?? throw new InvalidOperationException($"Type '{typeof(T)}' isn't an xsd enum");

        return attribute.Value ?? value.ToString();
    }

    public static IEnumerable<(T, string)> GetDescriptions<T>() where T : Enum
    {
        return Enum.GetValues(typeof(T)).Cast<T>().Select(x => (x, GetDescription(x)));
    }

    public static IDictionary<T, string> GetDescriptionsDictionary<T>() where T : Enum
    {
        return GetDescriptions<T>().ToDictionary(x => x.Item1, x => x.Item2);
    }

    public static string GetCommaSeperatedDescriptions<T>() where T : Enum
    {
        return string.Join(", ", GetDescriptions<T>().Select(x => x.Item2));
    }
}