﻿using SoapEndpoint.Service.Proxy.Infrastructure;
using SoapEndpoint.Service.Proxy.Models.Flows;
using SchuldbemiddelingMessageType = SoapEndpoint.Service.Systeem.v1.LogbookService.Berichttype;
using SbEnSkMessageType = SoapEndpoint.Service.Flows.SbEnSk.v1.LogbookService.BerichtType;
using BrEnHfMessageType = SoapEndpoint.Service.Flows.BrEnHf.v1.LogbookService.BerichtType;
using WaarborgfondsMessageType = SoapEndpoint.Service.Flows.Waarborgfonds.v1.LogbookService.BerichtType;
using InventarisatieMessageType = SoapEndpoint.Service.Flows.Inventarisatie.v1.LogbookService.BerichtType;
using BewindvoeringMessageType = SoapEndpoint.Service.Flows.Bewindvoering.v1.LogbookService.BerichtType;
using PauzeSignaal3MessageType = SoapEndpoint.Service.Flows.PauzeSignaal3.v1.LogbookService.BerichtType;
using ShvSignaalMessageType = SoapEndpoint.Service.Flows.ShvSignaal.v1.LogbookService.BerichtType;

namespace SoapEndpoint.Service.Proxy.ResourceItems;

public class ResourceItemManager
{
    public ResourceItemManager()
    {
        InitializeSchuldBemiddelingMessages();
        InitializeSkEnSbMessages();
        InitializeWaarborgfondsMessages();
        InitializeInventarisatieMessages();
        InitializeBrEnHfMessages();
        InitializeBewindvoeringMessages();
        InitializePauzeSignaal3Messages();
        InitializeShvSignaalMessages();
    }

    public IList<ResourceItem<SchuldbemiddelingMessageType>> SchuldBemiddelingResourceItems { get; } =
        new List<ResourceItem<SchuldbemiddelingMessageType>>();

    public IList<ResourceItem<SbEnSkMessageType>> SbEnSkResourceItems { get; } =
        new List<ResourceItem<SbEnSkMessageType>>();

    public IList<ResourceItem<WaarborgfondsMessageType>> WaarborgfondsResourceItems { get; } =
        new List<ResourceItem<WaarborgfondsMessageType>>();

    public IList<ResourceItem<InventarisatieMessageType>> InventarisatieResourceItems { get; } =
        new List<ResourceItem<InventarisatieMessageType>>();

    public IList<ResourceItem<BrEnHfMessageType>> BrEnHfResourceItems { get; } =
        new List<ResourceItem<BrEnHfMessageType>>();

    public IList<ResourceItem<BewindvoeringMessageType>> BewindvoeringResourceItems { get; } =
        new List<ResourceItem<BewindvoeringMessageType>>();

    public IList<ResourceItem<PauzeSignaal3MessageType>> PauzeSignaal3ResourceItems { get; } =
        new List<ResourceItem<PauzeSignaal3MessageType>>();

    public IList<ResourceItem<ShvSignaalMessageType>> ShvSignaalResourceItems { get; } =
        new List<ResourceItem<ShvSignaalMessageType>>();

    public ResourceItem<TMessageType>? GetSingleResource<TMessageType>(FlowType flowType, Version version,
        TMessageType messageType) where TMessageType : Enum
    {
        var itemList = flowType switch
        {
            FlowType.Schuldbemiddeling => SchuldBemiddelingResourceItems as IEnumerable<ResourceItem<TMessageType>>,
            FlowType.SbEnSk => SbEnSkResourceItems as IEnumerable<ResourceItem<TMessageType>>,
            FlowType.Waarborgfonds => WaarborgfondsResourceItems as IEnumerable<ResourceItem<TMessageType>>,
            FlowType.Inventarisatie => InventarisatieResourceItems as IEnumerable<ResourceItem<TMessageType>>,
            FlowType.BrEnHf => BrEnHfResourceItems as IEnumerable<ResourceItem<TMessageType>>,
            FlowType.Bewindvoering => BewindvoeringResourceItems as IEnumerable<ResourceItem<TMessageType>>,
            FlowType.PauzeSignaal3 => PauzeSignaal3ResourceItems as IEnumerable<ResourceItem<TMessageType>>,
            FlowType.ShvSignaal => ShvSignaalResourceItems as IEnumerable<ResourceItem<TMessageType>>,
            _ => throw new InvalidOperationException(
                $"No messages found based on the specified FlowType:{flowType}, Version:{version}, Berichttype:{messageType}")
        };

        return itemList?.Single(x =>
            x.TypeName != null && x.Berichttype != null && x.ResourceManagerModel.Version == version &&
            x.Berichttype.Equals(messageType) &&
            x.TypeName.Equals(Enum.GetName(typeof(TMessageType), messageType)));
    }

    public IEnumerable<ResourceItem<TMessageType>>? GetAllResources<TMessageType>(FlowType flowType, string version,
        bool isSeType)
        where TMessageType : Enum
    {
        var itemList = flowType switch
        {
            FlowType.Schuldbemiddeling => SchuldBemiddelingResourceItems as IEnumerable<ResourceItem<TMessageType>>,
            FlowType.SbEnSk => SbEnSkResourceItems as IEnumerable<ResourceItem<TMessageType>>,
            FlowType.Waarborgfonds => WaarborgfondsResourceItems as IEnumerable<ResourceItem<TMessageType>>,
            FlowType.Inventarisatie => InventarisatieResourceItems as IEnumerable<ResourceItem<TMessageType>>,
            FlowType.BrEnHf => BrEnHfResourceItems as IEnumerable<ResourceItem<TMessageType>>,
            FlowType.Bewindvoering => BewindvoeringResourceItems as IEnumerable<ResourceItem<TMessageType>>,
            FlowType.PauzeSignaal3 => PauzeSignaal3ResourceItems as IEnumerable<ResourceItem<TMessageType>>,
            FlowType.ShvSignaal => ShvSignaalResourceItems as IEnumerable<ResourceItem<TMessageType>>,
            _ => throw new InvalidOperationException(
                $"No messages found based on the specified FlowType:{flowType}, Version:{version}")
        };

        return itemList?.Where(x =>
            x.ResourceManagerModel.VersionAsString == version && x.Berichttype is not null && x.SeType == isSeType);
    }

    private void InitializeSchuldBemiddelingMessages()
    {
        #region V1.0 Berichten

        var versionOneZeroRm = new ResourceManagerModel(FlowType.Schuldbemiddeling, new Version(1, 0));
        // Version 1.0 SE berichten
        SchuldBemiddelingResourceItems.Add(new ResourceItem<SchuldbemiddelingMessageType>(versionOneZeroRm,
            SchuldbemiddelingMessageType.SE_KlantOnbekend));
        SchuldBemiddelingResourceItems.Add(new ResourceItem<SchuldbemiddelingMessageType>(versionOneZeroRm,
            SchuldbemiddelingMessageType.SE_KlantGemeldVoorShvAntwoord));
        SchuldBemiddelingResourceItems.Add(new ResourceItem<SchuldbemiddelingMessageType>(versionOneZeroRm,
            SchuldbemiddelingMessageType.SE_SaldoverzoekAntwoord));
        SchuldBemiddelingResourceItems.Add(new ResourceItem<SchuldbemiddelingMessageType>(versionOneZeroRm,
            SchuldbemiddelingMessageType.SE_BetaalvoorstelAntwoord));
        SchuldBemiddelingResourceItems.Add(new ResourceItem<SchuldbemiddelingMessageType>(versionOneZeroRm,
            SchuldbemiddelingMessageType.SE_Statusverzoek));
        SchuldBemiddelingResourceItems.Add(new ResourceItem<SchuldbemiddelingMessageType>(versionOneZeroRm,
            SchuldbemiddelingMessageType.SE_SaldoverzoekAntwoordStandaardAkkoord));
        SchuldBemiddelingResourceItems.Add(new ResourceItem<SchuldbemiddelingMessageType>(versionOneZeroRm,
            SchuldbemiddelingMessageType.SE_VerlorenBerichtVerzoek, "SE_VerlorenBerichtVerzoek"));

        //Version 1.0 SHV berichten
        SchuldBemiddelingResourceItems.Add(new ResourceItem<SchuldbemiddelingMessageType>(versionOneZeroRm,
            SchuldbemiddelingMessageType.SHV_KlantGemeldVoorShv));
        SchuldBemiddelingResourceItems.Add(new ResourceItem<SchuldbemiddelingMessageType>(versionOneZeroRm,
            SchuldbemiddelingMessageType.SHV_KlantBsnGemeldVoorShv));
        SchuldBemiddelingResourceItems.Add(new ResourceItem<SchuldbemiddelingMessageType>(versionOneZeroRm,
            SchuldbemiddelingMessageType.SHV_Saldoverzoek));
        SchuldBemiddelingResourceItems.Add(new ResourceItem<SchuldbemiddelingMessageType>(versionOneZeroRm,
            SchuldbemiddelingMessageType.SHV_SaldoverzoekNuts));
        SchuldBemiddelingResourceItems.Add(new ResourceItem<SchuldbemiddelingMessageType>(versionOneZeroRm,
            SchuldbemiddelingMessageType.SHV_SaldoverzoekPubliek));
        SchuldBemiddelingResourceItems.Add(new ResourceItem<SchuldbemiddelingMessageType>(versionOneZeroRm,
            SchuldbemiddelingMessageType.SHV_SaldoverzoekZorg));
        SchuldBemiddelingResourceItems.Add(new ResourceItem<SchuldbemiddelingMessageType>(versionOneZeroRm,
            SchuldbemiddelingMessageType.SHV_Betaalvoorstel));
        SchuldBemiddelingResourceItems.Add(new ResourceItem<SchuldbemiddelingMessageType>(versionOneZeroRm,
            SchuldbemiddelingMessageType.SHV_ReminderBericht));
        SchuldBemiddelingResourceItems.Add(new ResourceItem<SchuldbemiddelingMessageType>(versionOneZeroRm,
            SchuldbemiddelingMessageType.SHV_Statusbericht));
        SchuldBemiddelingResourceItems.Add(new ResourceItem<SchuldbemiddelingMessageType>(versionOneZeroRm,
            SchuldbemiddelingMessageType.SHV_SchuldregelingGeaccordeerd));
        SchuldBemiddelingResourceItems.Add(new ResourceItem<SchuldbemiddelingMessageType>(versionOneZeroRm,
            SchuldbemiddelingMessageType.SHV_SchuldregelingBeeindigd));
        SchuldBemiddelingResourceItems.Add(new ResourceItem<SchuldbemiddelingMessageType>(versionOneZeroRm,
            SchuldbemiddelingMessageType.SHV_VerlorenBerichtVerzoek, "SHV_VerlorenBerichtVerzoek"));

        #endregion

        #region V1.1 Berichten

        var versionOneOneRm = new ResourceManagerModel(FlowType.Schuldbemiddeling, new Version(1, 1));
        // SE berichten
        SchuldBemiddelingResourceItems.Add(new ResourceItem<SchuldbemiddelingMessageType>(versionOneOneRm,
            SchuldbemiddelingMessageType.SE_KlantOnbekend));
        SchuldBemiddelingResourceItems.Add(new ResourceItem<SchuldbemiddelingMessageType>(versionOneOneRm,
            SchuldbemiddelingMessageType.SE_KlantGemeldVoorShvAntwoord));
        SchuldBemiddelingResourceItems.Add(new ResourceItem<SchuldbemiddelingMessageType>(versionOneOneRm,
            SchuldbemiddelingMessageType.SE_SaldoverzoekAntwoord));
        SchuldBemiddelingResourceItems.Add(new ResourceItem<SchuldbemiddelingMessageType>(versionOneOneRm,
            SchuldbemiddelingMessageType.SE_BetaalvoorstelAntwoord));
        SchuldBemiddelingResourceItems.Add(new ResourceItem<SchuldbemiddelingMessageType>(versionOneOneRm,
            SchuldbemiddelingMessageType.SE_Statusverzoek));
        SchuldBemiddelingResourceItems.Add(new ResourceItem<SchuldbemiddelingMessageType>(versionOneOneRm,
            SchuldbemiddelingMessageType.SE_SaldoverzoekAntwoordStandaardAkkoord));
        SchuldBemiddelingResourceItems.Add(new ResourceItem<SchuldbemiddelingMessageType>(versionOneOneRm,
            SchuldbemiddelingMessageType.SE_VerlorenBerichtVerzoek, "SE_VerlorenBerichtVerzoek"));

        // SHV berichten
        SchuldBemiddelingResourceItems.Add(new ResourceItem<SchuldbemiddelingMessageType>(versionOneOneRm,
            SchuldbemiddelingMessageType.SHV_KlantGemeldVoorShv));
        SchuldBemiddelingResourceItems.Add(new ResourceItem<SchuldbemiddelingMessageType>(versionOneOneRm,
            SchuldbemiddelingMessageType.SHV_KlantBsnGemeldVoorShv));
        SchuldBemiddelingResourceItems.Add(new ResourceItem<SchuldbemiddelingMessageType>(versionOneOneRm,
            SchuldbemiddelingMessageType.SHV_Saldoverzoek));
        SchuldBemiddelingResourceItems.Add(new ResourceItem<SchuldbemiddelingMessageType>(versionOneOneRm,
            SchuldbemiddelingMessageType.SHV_SaldoverzoekNuts));
        SchuldBemiddelingResourceItems.Add(new ResourceItem<SchuldbemiddelingMessageType>(versionOneOneRm,
            SchuldbemiddelingMessageType.SHV_SaldoverzoekPubliek));
        SchuldBemiddelingResourceItems.Add(new ResourceItem<SchuldbemiddelingMessageType>(versionOneOneRm,
            SchuldbemiddelingMessageType.SHV_SaldoverzoekZorg));
        SchuldBemiddelingResourceItems.Add(new ResourceItem<SchuldbemiddelingMessageType>(versionOneOneRm,
            SchuldbemiddelingMessageType.SHV_Betaalvoorstel));
        SchuldBemiddelingResourceItems.Add(new ResourceItem<SchuldbemiddelingMessageType>(versionOneOneRm,
            SchuldbemiddelingMessageType.SHV_ReminderBericht));
        SchuldBemiddelingResourceItems.Add(new ResourceItem<SchuldbemiddelingMessageType>(versionOneOneRm,
            SchuldbemiddelingMessageType.SHV_Statusbericht));
        SchuldBemiddelingResourceItems.Add(new ResourceItem<SchuldbemiddelingMessageType>(versionOneOneRm,
            SchuldbemiddelingMessageType.SHV_SchuldregelingGeaccordeerd));
        SchuldBemiddelingResourceItems.Add(new ResourceItem<SchuldbemiddelingMessageType>(versionOneOneRm,
            SchuldbemiddelingMessageType.SHV_SchuldregelingBeeindigd));
        SchuldBemiddelingResourceItems.Add(new ResourceItem<SchuldbemiddelingMessageType>(versionOneOneRm,
            SchuldbemiddelingMessageType.SHV_VerlorenBerichtVerzoek, "SHV_VerlorenBerichtVerzoek"));

        #endregion
    }

    private void InitializeSkEnSbMessages()
    {
        #region V1.0 Berichten

        var versionOneZeroRm = new ResourceManagerModel(FlowType.SbEnSk, new Version(1, 0));
        // SE berichten
        SbEnSkResourceItems.Add(
            new ResourceItem<SbEnSkMessageType>(versionOneZeroRm, SbEnSkMessageType.SE_GeenMedewerking));
        SbEnSkResourceItems.Add(
            new ResourceItem<SbEnSkMessageType>(versionOneZeroRm, SbEnSkMessageType.SE_KennisgevingAntwoord));
        SbEnSkResourceItems.Add(
            new ResourceItem<SbEnSkMessageType>(versionOneZeroRm, SbEnSkMessageType.SE_SaldoverzoekAntwoord));
        SbEnSkResourceItems.Add(new ResourceItem<SbEnSkMessageType>(versionOneZeroRm,
            SbEnSkMessageType.SE_SaldoverzoekAntwoordVoorafAkkoord));
        SbEnSkResourceItems.Add(new ResourceItem<SbEnSkMessageType>(versionOneZeroRm,
            SbEnSkMessageType.SE_BetaalvoorstelAntwoordAkkoord));
        SbEnSkResourceItems.Add(new ResourceItem<SbEnSkMessageType>(versionOneZeroRm,
            SbEnSkMessageType.SE_BetaalvoorstelAntwoordNietAkkoord));
        SbEnSkResourceItems.Add(
            new ResourceItem<SbEnSkMessageType>(versionOneZeroRm, SbEnSkMessageType.SE_StatusberichtSe));
        SbEnSkResourceItems.Add(
            new ResourceItem<SbEnSkMessageType>(versionOneZeroRm, SbEnSkMessageType.SE_Statusverzoek));
        SbEnSkResourceItems.Add(
            new ResourceItem<SbEnSkMessageType>(versionOneZeroRm, SbEnSkMessageType.SE_VtlbVerzoek));
        SbEnSkResourceItems.Add(new ResourceItem<SbEnSkMessageType>(versionOneZeroRm,
            SbEnSkMessageType.SE_VerlorenBerichtVerzoek, "SE_VerlorenBerichtVerzoek"));

        // SHV berichten
        SbEnSkResourceItems.Add(
            new ResourceItem<SbEnSkMessageType>(versionOneZeroRm, SbEnSkMessageType.SHV_Kennisgeving));
        SbEnSkResourceItems.Add(
            new ResourceItem<SbEnSkMessageType>(versionOneZeroRm, SbEnSkMessageType.SHV_KennisgevingPubliek));
        SbEnSkResourceItems.Add(
            new ResourceItem<SbEnSkMessageType>(versionOneZeroRm, SbEnSkMessageType.SHV_Saldoverzoek));
        SbEnSkResourceItems.Add(
            new ResourceItem<SbEnSkMessageType>(versionOneZeroRm, SbEnSkMessageType.SHV_SaldoverzoekNuts));
        SbEnSkResourceItems.Add(
            new ResourceItem<SbEnSkMessageType>(versionOneZeroRm, SbEnSkMessageType.SHV_SaldoverzoekPubliek));
        SbEnSkResourceItems.Add(
            new ResourceItem<SbEnSkMessageType>(versionOneZeroRm, SbEnSkMessageType.SHV_SaldoverzoekZorg));
        SbEnSkResourceItems.Add(
            new ResourceItem<SbEnSkMessageType>(versionOneZeroRm, SbEnSkMessageType.SHV_Betaalvoorstel));
        SbEnSkResourceItems.Add(
            new ResourceItem<SbEnSkMessageType>(versionOneZeroRm, SbEnSkMessageType.SHV_BetaalvoorstelVtlb));
        SbEnSkResourceItems.Add(new ResourceItem<SbEnSkMessageType>(versionOneZeroRm,
            SbEnSkMessageType.SHV_RegelingGeaccordeerd));
        SbEnSkResourceItems.Add(
            new ResourceItem<SbEnSkMessageType>(versionOneZeroRm, SbEnSkMessageType.SHV_Heroverweging));
        SbEnSkResourceItems.Add(new ResourceItem<SbEnSkMessageType>(versionOneZeroRm,
            SbEnSkMessageType.SHV_Beeindiging));
        SbEnSkResourceItems.Add(
            new ResourceItem<SbEnSkMessageType>(versionOneZeroRm, SbEnSkMessageType.SHV_StatusberichtShv));
        SbEnSkResourceItems.Add(
            new ResourceItem<SbEnSkMessageType>(versionOneZeroRm, SbEnSkMessageType.SHV_ReminderBericht));
        SbEnSkResourceItems.Add(new ResourceItem<SbEnSkMessageType>(versionOneZeroRm,
            SbEnSkMessageType.SHV_VerlorenBerichtVerzoek, "SHV_VerlorenBerichtVerzoek"));

        #endregion
    }

    private void InitializeWaarborgfondsMessages()
    {
        #region V1.0 Berichten

        var versionOneZeroRm = new ResourceManagerModel(FlowType.Waarborgfonds, new Version(1, 0));
        // SE berichten
        WaarborgfondsResourceItems.Add(new ResourceItem<WaarborgfondsMessageType>(versionOneZeroRm,
            WaarborgfondsMessageType.SE_ProFormaBorgstellingAfgegeven));
        WaarborgfondsResourceItems.Add(new ResourceItem<WaarborgfondsMessageType>(versionOneZeroRm,
            WaarborgfondsMessageType.SE_ProFormaAanvraagAfgewezen));
        WaarborgfondsResourceItems.Add(new ResourceItem<WaarborgfondsMessageType>(versionOneZeroRm,
            WaarborgfondsMessageType.SE_BorgstellingIngetrokken));
        WaarborgfondsResourceItems.Add(new ResourceItem<WaarborgfondsMessageType>(versionOneZeroRm,
            WaarborgfondsMessageType.SE_BorgstellingBeeindigd));
        WaarborgfondsResourceItems.Add(new ResourceItem<WaarborgfondsMessageType>(versionOneZeroRm,
            WaarborgfondsMessageType.SE_BorgstellingAfgegeven));
        WaarborgfondsResourceItems.Add(new ResourceItem<WaarborgfondsMessageType>(versionOneZeroRm,
            WaarborgfondsMessageType.SE_BorgstellingAanvraagBeeindigd));
        WaarborgfondsResourceItems.Add(new ResourceItem<WaarborgfondsMessageType>(versionOneZeroRm,
            WaarborgfondsMessageType.SE_BorgstellingAanvraagAfgewezen));
        WaarborgfondsResourceItems.Add(new ResourceItem<WaarborgfondsMessageType>(versionOneZeroRm,
            WaarborgfondsMessageType.SE_UitbetaalverzoekAfgewezen));
        WaarborgfondsResourceItems.Add(new ResourceItem<WaarborgfondsMessageType>(versionOneZeroRm,
            WaarborgfondsMessageType.SE_BorgstellingUitbetaald));
        WaarborgfondsResourceItems.Add(new ResourceItem<WaarborgfondsMessageType>(versionOneZeroRm,
            WaarborgfondsMessageType.SE_WaarborgfondsFoutbericht));
        WaarborgfondsResourceItems.Add(new ResourceItem<WaarborgfondsMessageType>(versionOneZeroRm,
            WaarborgfondsMessageType.SE_SaneringskredietInformatieAanvraag));

        // SHV berichten
        WaarborgfondsResourceItems.Add(new ResourceItem<WaarborgfondsMessageType>(versionOneZeroRm,
            WaarborgfondsMessageType.SHV_RegistreerProFormaAanvraag));
        WaarborgfondsResourceItems.Add(new ResourceItem<WaarborgfondsMessageType>(versionOneZeroRm,
            WaarborgfondsMessageType.SHV_AanvraagBorgstelling));
        WaarborgfondsResourceItems.Add(
            new ResourceItem<WaarborgfondsMessageType>(versionOneZeroRm,
                WaarborgfondsMessageType.SHV_AanvraagOvername));
        WaarborgfondsResourceItems.Add(new ResourceItem<WaarborgfondsMessageType>(versionOneZeroRm,
            WaarborgfondsMessageType.SHV_BeeindigingBorgstelling));
        WaarborgfondsResourceItems.Add(new ResourceItem<WaarborgfondsMessageType>(versionOneZeroRm,
            WaarborgfondsMessageType.SHV_BorgstellingUitbetalen));
        WaarborgfondsResourceItems.Add(new ResourceItem<WaarborgfondsMessageType>(versionOneZeroRm,
            WaarborgfondsMessageType.SHV_VerwerkSaneringskredietenInformatie));

        #endregion
    }

    private void InitializeInventarisatieMessages()
    {
        #region V1.0 Berichten

        var versionOneZeroRm = new ResourceManagerModel(FlowType.Inventarisatie, new Version(1, 0));
        // Version 1.0 SE berichten
        InventarisatieResourceItems.Add(new ResourceItem<InventarisatieMessageType>(versionOneZeroRm,
            InventarisatieMessageType.SE_GeenMedewerking));
        InventarisatieResourceItems.Add(new ResourceItem<InventarisatieMessageType>(versionOneZeroRm,
            InventarisatieMessageType.SE_SaldoverzoekAntwoord));
        InventarisatieResourceItems.Add(new ResourceItem<InventarisatieMessageType>(versionOneZeroRm,
            InventarisatieMessageType.SE_StatusberichtSe));

        // Version 1.0 SHV berichten
        InventarisatieResourceItems.Add(new ResourceItem<InventarisatieMessageType>(versionOneZeroRm,
            InventarisatieMessageType.SHV_Saldoverzoek));
        InventarisatieResourceItems.Add(new ResourceItem<InventarisatieMessageType>(versionOneZeroRm,
            InventarisatieMessageType.SHV_SaldoverzoekNuts));
        InventarisatieResourceItems.Add(new ResourceItem<InventarisatieMessageType>(versionOneZeroRm,
            InventarisatieMessageType.SHV_SaldoverzoekZorg));
        InventarisatieResourceItems.Add(new ResourceItem<InventarisatieMessageType>(versionOneZeroRm,
            InventarisatieMessageType.SHV_SaldoverzoekPubliek));
        InventarisatieResourceItems.Add(new ResourceItem<InventarisatieMessageType>(versionOneZeroRm,
            InventarisatieMessageType.SHV_ReminderBericht));
        InventarisatieResourceItems.Add(new ResourceItem<InventarisatieMessageType>(versionOneZeroRm,
            InventarisatieMessageType.SHV_Beeindiging));
        InventarisatieResourceItems.Add(new ResourceItem<InventarisatieMessageType>(versionOneZeroRm,
            InventarisatieMessageType.SHV_StatusberichtShv));

        #endregion
    }

    private void InitializeBrEnHfMessages()
    {
        #region V1.0 Berichten

        var versionOneZeroRm = new ResourceManagerModel(FlowType.BrEnHf, new Version(1, 0));
        // SE berichten
        BrEnHfResourceItems.Add(
            new ResourceItem<BrEnHfMessageType>(versionOneZeroRm, BrEnHfMessageType.SE_GeenMedewerking));
        BrEnHfResourceItems.Add(
            new ResourceItem<BrEnHfMessageType>(versionOneZeroRm, BrEnHfMessageType.SE_KennisgevingAntwoord));
        BrEnHfResourceItems.Add(
            new ResourceItem<BrEnHfMessageType>(versionOneZeroRm, BrEnHfMessageType.SE_SaldoverzoekAntwoord));
        BrEnHfResourceItems.Add(new ResourceItem<BrEnHfMessageType>(versionOneZeroRm,
            BrEnHfMessageType.SE_SaldoverzoekAntwoordVoorafAkkoord));
        BrEnHfResourceItems.Add(new ResourceItem<BrEnHfMessageType>(versionOneZeroRm,
            BrEnHfMessageType.SE_BetaalvoorstelAntwoordAkkoord));
        BrEnHfResourceItems.Add(new ResourceItem<BrEnHfMessageType>(versionOneZeroRm,
            BrEnHfMessageType.SE_BetaalvoorstelAntwoordNietAkkoord));
        BrEnHfResourceItems.Add(
            new ResourceItem<BrEnHfMessageType>(versionOneZeroRm, BrEnHfMessageType.SE_StatusberichtSe));
        BrEnHfResourceItems.Add(
            new ResourceItem<BrEnHfMessageType>(versionOneZeroRm, BrEnHfMessageType.SE_Statusverzoek));

        // SHV berichten
        BrEnHfResourceItems.Add(
            new ResourceItem<BrEnHfMessageType>(versionOneZeroRm, BrEnHfMessageType.SHV_Kennisgeving));
        BrEnHfResourceItems.Add(
            new ResourceItem<BrEnHfMessageType>(versionOneZeroRm, BrEnHfMessageType.SHV_KennisgevingPubliek));
        BrEnHfResourceItems.Add(
            new ResourceItem<BrEnHfMessageType>(versionOneZeroRm, BrEnHfMessageType.SHV_Saldoverzoek));
        BrEnHfResourceItems.Add(
            new ResourceItem<BrEnHfMessageType>(versionOneZeroRm, BrEnHfMessageType.SHV_SaldoverzoekNuts));
        BrEnHfResourceItems.Add(
            new ResourceItem<BrEnHfMessageType>(versionOneZeroRm, BrEnHfMessageType.SHV_SaldoverzoekPubliek));
        BrEnHfResourceItems.Add(
            new ResourceItem<BrEnHfMessageType>(versionOneZeroRm, BrEnHfMessageType.SHV_SaldoverzoekZorg));
        BrEnHfResourceItems.Add(
            new ResourceItem<BrEnHfMessageType>(versionOneZeroRm, BrEnHfMessageType.SHV_Betaalvoorstel));
        BrEnHfResourceItems.Add(new ResourceItem<BrEnHfMessageType>(versionOneZeroRm,
            BrEnHfMessageType.SHV_RegelingGeaccordeerd));
        BrEnHfResourceItems.Add(new ResourceItem<BrEnHfMessageType>(versionOneZeroRm,
            BrEnHfMessageType.SHV_Beeindiging));
        BrEnHfResourceItems.Add(
            new ResourceItem<BrEnHfMessageType>(versionOneZeroRm, BrEnHfMessageType.SHV_StatusberichtShv));
        BrEnHfResourceItems.Add(
            new ResourceItem<BrEnHfMessageType>(versionOneZeroRm, BrEnHfMessageType.SHV_ReminderBericht));
        BrEnHfResourceItems.Add(new ResourceItem<BrEnHfMessageType>(versionOneZeroRm,
            BrEnHfMessageType.SHV_VerlorenBerichtVerzoek, "SHV_VerlorenBerichtVerzoek"));

        #endregion
    }

    private void InitializeBewindvoeringMessages()
    {
        #region V1.0 Berichten

        var versionOneZeroRm = new ResourceManagerModel(FlowType.Bewindvoering, new Version(1, 0));
        // Version 1.0 SE berichten
        BewindvoeringResourceItems.Add(new ResourceItem<BewindvoeringMessageType>(versionOneZeroRm,
            BewindvoeringMessageType.SE_AntwoordMeldingBewind));

        // Version 1.0 SHV berichten
        BewindvoeringResourceItems.Add(new ResourceItem<BewindvoeringMessageType>(versionOneZeroRm,
            BewindvoeringMessageType.SHV_StartBewind));
        BewindvoeringResourceItems.Add(new ResourceItem<BewindvoeringMessageType>(versionOneZeroRm,
            BewindvoeringMessageType.SHV_StartBewindPubliek));
        BewindvoeringResourceItems.Add(new ResourceItem<BewindvoeringMessageType>(versionOneZeroRm,
            BewindvoeringMessageType.SHV_ActualisatieBewindgegevens));
        BewindvoeringResourceItems.Add(new ResourceItem<BewindvoeringMessageType>(versionOneZeroRm,
            BewindvoeringMessageType.SHV_ActualisatieBewindgegevensPubliek));
        BewindvoeringResourceItems.Add(new ResourceItem<BewindvoeringMessageType>(versionOneZeroRm,
            BewindvoeringMessageType.SHV_EindeBewind));
        BewindvoeringResourceItems.Add(new ResourceItem<BewindvoeringMessageType>(versionOneZeroRm,
            BewindvoeringMessageType.SHV_EindeBewindPubliek));
        BewindvoeringResourceItems.Add(new ResourceItem<BewindvoeringMessageType>(versionOneZeroRm,
            BewindvoeringMessageType.SHV_VerlorenBerichtVerzoek, "SHV_VerlorenBerichtVerzoek"));

        #endregion
    }

    private void InitializePauzeSignaal3Messages()
    {
        #region V1.0 Berichten

        var versionOneZeroRm = new ResourceManagerModel(FlowType.PauzeSignaal3, new Version(1, 0));
        // SE berichten
        PauzeSignaal3ResourceItems.Add(
            new ResourceItem<PauzeSignaal3MessageType>(versionOneZeroRm, PauzeSignaal3MessageType.SE_GeenMedewerking));
        PauzeSignaal3ResourceItems.Add(
            new ResourceItem<PauzeSignaal3MessageType>(versionOneZeroRm,
                PauzeSignaal3MessageType.SE_KennisgevingAntwoord));
        PauzeSignaal3ResourceItems.Add(
            new ResourceItem<PauzeSignaal3MessageType>(versionOneZeroRm, PauzeSignaal3MessageType.SE_Statusverzoek));

        // SHV berichten
        PauzeSignaal3ResourceItems.Add(
            new ResourceItem<PauzeSignaal3MessageType>(versionOneZeroRm, PauzeSignaal3MessageType.SHV_Kennisgeving));
        PauzeSignaal3ResourceItems.Add(
            new ResourceItem<PauzeSignaal3MessageType>(versionOneZeroRm,
                PauzeSignaal3MessageType.SHV_KennisgevingPubliek));
        PauzeSignaal3ResourceItems.Add(
            new ResourceItem<PauzeSignaal3MessageType>(versionOneZeroRm, PauzeSignaal3MessageType.SHV_Beeindiging));
        PauzeSignaal3ResourceItems.Add(new ResourceItem<PauzeSignaal3MessageType>(versionOneZeroRm,
            PauzeSignaal3MessageType.SHV_Vervolgtraject));
        PauzeSignaal3ResourceItems.Add(
            new ResourceItem<PauzeSignaal3MessageType>(versionOneZeroRm,
                PauzeSignaal3MessageType.SHV_StatusberichtShv));
        PauzeSignaal3ResourceItems.Add(
            new ResourceItem<PauzeSignaal3MessageType>(versionOneZeroRm, PauzeSignaal3MessageType.SHV_ReminderBericht));

        #endregion
    }

    private void InitializeShvSignaalMessages()
    {
        #region V1.0 Berichten

        var versionOneZeroRm = new ResourceManagerModel(FlowType.ShvSignaal, new Version(1, 0));

        // SHV berichten
        ShvSignaalResourceItems.Add(
            new ResourceItem<ShvSignaalMessageType>(versionOneZeroRm, ShvSignaalMessageType.SHV_ShvSignaal));
        ShvSignaalResourceItems.Add(
            new ResourceItem<ShvSignaalMessageType>(versionOneZeroRm,
                ShvSignaalMessageType.SHV_AntwoordShvSignaal));

        #endregion
    }
}